import { SqliteTools } from "../src/sqlite-tools";
import { ListenerRSSInfos } from "listener-rss";

// testing
import * as chai from "chai";
import sinon from "ts-sinon";
import sinonChai from "sinon-chai";

import { withFile } from "tmp-promise";

chai.use(sinonChai);

const expect = chai.expect;

const dataWithHistory: ListenerRSSInfos[] = require("./RessourcesTest/RealRessources/save.json");
const dataWithoutHistory = dataWithHistory.map((data) => ({
  ...data,
  lastEntriesLinks: [],
}));
describe("test sqlite tools class", () => {
  it("should create a .db file and fill him", async () => {
    await withFile(async ({ path }) => {
      // given
      const dbTools = new SqliteTools(path);
      await dbTools.ensureTableExists();

      // when
      const oldValues: ListenerRSSInfos[] = await dbTools.fetchAll();
      for (const item of dataWithoutHistory) await dbTools.insertListener(item);
      const newValues: ListenerRSSInfos[] = await dbTools.fetchAll();

      // expect
      expect(oldValues).to.be.empty;
      expect(newValues).to.have.lengthOf(3);

      expect(newValues).to.be.eql(dataWithoutHistory);
    });
  });

  it("should update the values of the databases", async () => {
    await withFile(async ({ path }) => {
      // given
      const dbTools = new SqliteTools(path);
      await dbTools.ensureTableExists();
      for (const item of dataWithoutHistory) await dbTools.insertListener(item);

      //when
      await dbTools.updateAll(dataWithHistory);
      const values: ListenerRSSInfos[] = await dbTools.fetchAll();

      expect(values).to.be.eql(dataWithHistory);
    });
  });
});
